@@ -135,7 +135,7 @@ class App(object):
                    (self.__ctrlbar.set_visible, [True]),                   
                    (self.__root_pane.render, []),
                    (self.__scan_media, [True]),
-                   (self.__ctrlbar.select_tab, [0]),
+                   (self.__ctrlbar.select_tab, [1]),
                    (self.__setup_mmc_replacement_detection, []),
                    ]
                    
@@ -419,6 +419,12 @@ class App(object):
         elif (cmd == src.OBS_SHOW_PANEL):
             self.__ctrlbar.show_panel()
 
+        elif (cmd == src.OBS_STOP_PLAYING):
+            issuer = args[0]
+            # call all viewers to stop playing
+            for v in self.__viewers:
+                v.stop_playing(issuer)
+
 
     def __on_observe_ctrlbar(self, src, cmd, *args):
     
