@@ -179,14 +179,16 @@ class _MPlayer(GenericMediaPlayer):
                 self.__player_values[_ICY_INFO] = None
             
             # check for end of file
-            if (self.__player_values[_FILENAME]):
-                self.__next_time_check = now + 1
-            elif (now > self.__next_time_check):            
-                self.__on_eof()
-                self.__next_time_check = now + 1
+            if (total > 0 and pos >= total):
+                if (self.__player_values[_FILENAME]):
+                    self.__next_time_check = now + 1
+                elif (now > self.__next_time_check):            
+                    self.__on_eof()
+                    self.__next_time_check = now + 1
 
-            self.__player_values[_FILENAME] = None
-            self.__send_cmd("get_property filename")
+                self.__player_values[_FILENAME] = None
+                self.__send_cmd("get_property filename")
+            #end if
 
             self.update_observer(self.OBS_POSITION, self.__context_id,
                                  pos, total)
@@ -532,6 +534,9 @@ class _MPlayer(GenericMediaPlayer):
 
         self.__player_values[_FILENAME] = filename
 
+        # reset position bar
+        self.update_observer(self.OBS_POSITION, self.__context_id, 0, 0.01)
+
         #cnt = 0
         #while (not self.__playing and not self.__broken):
         #    self.__collect_values()
