@@ -1,4 +1,5 @@
 from viewers.Viewer import Viewer
+from ui.KineticScroller import KineticScroller
 from SunClock import SunClock
 import theme
 
@@ -14,21 +15,21 @@ class Clock(Viewer):
     ICON = theme.viewer_clock
     ICON_ACTIVE = theme.viewer_clock_active
     PRIORITY = 100
-    BORDER_WIDTH = 0
-    IS_EXPERIMENTAL = False
-    
+   
 
-    def __init__(self):
+    def __init__(self, esens):
     
         self.__is_ticking = False
     
-        Viewer.__init__(self)
-                
-        self.__sunclock = SunClock()
-        self.set_widget(self.__sunclock)
-        
-        #gobject.timeout_add(10000, self.__tick)
-        
+        Viewer.__init__(self, esens)
+
+        self.__sunclock = SunClock(esens)
+        self.add(self.__sunclock)
+
+        # kinetic panning of the earth background is not optimized for speed
+        # yet
+        #kscr = KineticScroller(self.__sunclock)
+              
         
     def __tick(self):
     
@@ -44,8 +45,7 @@ class Clock(Viewer):
     
         Viewer.show(self)
         self.update_observer(self.OBS_HIDE_COLLECTION)
-        gobject.idle_add(self.__sunclock.update)
-        
+                   
         self.__tick()
         if (not self.__is_ticking):
             gobject.timeout_add(10000, self.__tick)
